% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kfino.R
\name{kfino_fit}
\alias{kfino_fit}
\title{kfino_fit a function to detect outlier with a Kalman Filtering approach}
\usage{
kfino_fit(
  datain,
  Tvar,
  Yvar,
  param = NULL,
  doOptim = TRUE,
  method = "ML",
  threshold = 0.5,
  kappa = 10,
  kappaOpt = 7
)
}
\arguments{
\item{datain}{an input data.frame of one time course to study (unique IDE)}

\item{Tvar}{char, time column name in the data.frame datain, a numeric vector
Tvar can be expressed as a proportion of day in seconds}

\item{Yvar}{char, name of the variable to predict in the data.frame datain}

\item{param}{list, a list of initialization parameters}

\item{doOptim}{logical, if TRUE optimisation of the initial parameters
default TRUE}

\item{method}{character, the method used to optimize the initial parameters:
Expectation-Maximization algorithm `"EM"` or Maximization 
Likelihhod `"ML"`, default `"ML"`}

\item{threshold}{numeric, threshold to qualify an observation as outlier
according to the label_pred, default 0.5}

\item{kappa}{numeric, truncation setting, default 10}

\item{kappaOpt}{numeric, truncation setting, default 7}
}
\value{
a S3 list with two data frames and a list of vectors of
kfino results
\describe{
\item{detectOutlier}{The whole dataset with the detected outliers flagged
                     and prediction}
\item{PredictionOK}{A dataset with the predictions on possible values}
\item{kafino.results}{kfino results (a list of vectors) on optimized input
                     parameters or not}
}
}
\description{
kfino_fit a function to detect outlier with a Kalman Filtering approach
}
\details{
The initialization parameter list param contains:
\describe{
 \item{mm}{(optional) target weight, NULL if the user wants to optimize it}
 \item{pp}{(optional) probability to be correctly weighed, NULL if the user
           wants to optimize it}
 \item{m0}{(optional) Initial weight, NULL if the user wants to optimize it}
 \item{aa}{numeric, rate of weight change, default 0.001 }
 \item{expertMin}{numeric, the minimal weight expected by the user}
 \item{expertMax}{numeric, the maximal weight expected by the user}
 \item{sigma2_m0}{variance of m0, default 1}
 \item{sigma2_mm}{numeric, variance of mm, related to the unit of Tvar,
       default 0.05}
 \item{sigma2_pp}{numeric, variance of pp, related to the unit of Yvar,
       default 5}
 \item{K}{numeric, a constant value in the outlier function (trapezium),
          by default K=5}
 \item{seqp}{numeric, sequence of pp probability to be correctly weighted.
             default seq(0.5,0.7,0.1)}
}
It has to be given by the user following his knowledge of the animal or
the dataset. All parameters are compulsory except m0, mm and pp that can be
optimized by the algorithm. In the optimization step, those three parameters
are initialized according to the input data (between the expert
range) using quantile of the Y distribution (varying between 0.2 and 0.8 for
m0 and 0.5 for mm). pp is a sequence varying between 0.5 and 0.7. A
sub-sampling is performed to speed the algorithm if the number of possible
observations studied is greater than 500. Optimization is performed using 
`"EM"` or `"ML"` methods.
}
\examples{
data(spring1)
library(dplyr)

# --- With Optimisation on initial parameters - ML method
t0 <- Sys.time()
param1<-list(m0=NULL,
             mm=NULL,
             pp=NULL,
             aa=0.001,
             expertMin=30,
             expertMax=75,
             sigma2_m0=1,
             sigma2_mm=0.05,
             sigma2_pp=5,
             K=2,
             seqp=seq(0.5,0.7,0.1))

resu1<-kfino_fit(datain=spring1,
              Tvar="dateNum",Yvar="Poids",
              doOptim=TRUE,method="ML",param=param1)
Sys.time() - t0

# --- With Optimisation on initial parameters - EM method
t0 <- Sys.time()
resu1b<-kfino_fit(datain=spring1,
              Tvar="dateNum",Yvar="Poids",
              doOptim=TRUE,method="EM",param=param1)
Sys.time() - t0

# --- Without Optimisation on initial parameters
t0 <- Sys.time()
param2<-list(m0=41,
             mm=45,
             pp=0.5,
             aa=0.001,
             expertMin=30,
             expertMax=75,
             sigma2_m0=1,
             sigma2_mm=0.05,
             sigma2_pp=5,
             K=2,
             seqp=seq(0.5,0.7,0.1))
resu2<-kfino_fit(datain=spring1,
              Tvar="dateNum",Yvar="Poids",
              param=param2,
              doOptim=FALSE)
Sys.time() - t0

# complex data on merinos2 dataset
data(merinos2)

t0 <- Sys.time()
param3<-list(m0=NULL,
             mm=NULL,
             pp=NULL,
             aa=0.001,
             expertMin=10,
             expertMax=45,
             sigma2_m0=1,
             sigma2_mm=0.05,
             sigma2_pp=5,
             K=2,
             seqp=seq(0.5,0.7,0.1))
resu3<-kfino_fit(datain=merinos2,
              Tvar="dateNum",Yvar="Poids",
              doOptim=TRUE,method="ML",param=param3)
Sys.time() - t0
}
